@@ -9,11 +9,11 @@
 __author__      = ["Claudio D'Onofrio"]
 __credits__     = "ICOS Carbon Portal"
 __license__     = "GPL-3.0"
-__version__     = "0.1.5"
+__version__     = "0.1.6"
 __maintainer__  = "ICOS Carbon Portal, elaborated products team"
 __email__       = ['info@icos-cp.eu', 'claudio.donofrio@nateko.lu.se']
 __status__      = "rc1"
-__date__        = "2020-10-20"
+__date__        = "2021-06-15"
 
 import os
 import requests
@@ -50,6 +50,7 @@ class Dobj():
         self._dobjValid = False     # -> see __getPayload()
         
         self.citation = None        # hold the citation string for the object
+        self._licence = None         # hold the licence links and text
         
         self._data = pd.DataFrame() # This holds the data pandas dataframe
                                     # persistent in the object. 
@@ -133,9 +134,20 @@ class Dobj():
         if self._dobjValid:
             return [self._info1, self._info2, self._info3]
         return None 
+    #-----------    
+    @property
+    def licence(self):
+        if self._dobjValid:
+            return self.__licence()
+        return None 
     #-----------
-
 # -------------------------------------------------    
+
+    def __str__(self):
+        out = str(self.info[0].iloc[0]['dobj'])
+        return out
+    
+        
     def get(self):
         """ return data as pandas data frame"""
         return self.getColumns()
@@ -373,13 +385,20 @@ class Dobj():
     # -------------------------------------------------                       
     def __portalUse(self):
         
-        """ private function to track data usage """        
+        """ private function to track data usage """    
+        #check if used on our own jupyter hub servers
+        if os.path.isdir(self._localpath):
+            internal = 'True'
+        else: 
+            internal = 'False'
+        
         counter = {'BinaryFileDownload':{
         'params':{
             'objId':self._dobj,
             'columns': self.colNames.tolist(),            
             'library':__name__, 
-            'version':__version__}
+            'version':__version__,
+            'internal': internal}
             }
         }
         server = 'https://cpauth.icos-cp.eu/logs/portaluse'        
@@ -447,6 +466,18 @@ class Dobj():
         import icoscp.cpb.get_size as s
         return s.get(self)
     
+    # -------------------------------------------------------------
+    def __licence(self):
+        """
+        Licence associated for this data object. 
+
+        Returns
+        -------
+        DICT : conotaining the the licence text and url
+
+        """
+        return {'licence':'CC BY 4.0', 'url': 'https://data.icos-cp.eu/licence' }
+    
 if __name__ == "__main__":
     """
     execute only if run as a script
